@@ -12,6 +12,7 @@ import argparse
 
 from hamunafs.utils.nsqmanager import MQManager
 from hamunafs.sqlite import DB
+from hamunafs.utils.timeutil import is_time_in_range
 
 def get_opts():
     parser = argparse.ArgumentParser()
@@ -87,14 +88,14 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                 ret, e = await hmfs_client.get_from_cloud_async(file_path, url)
 
                 if ret:
-                    # print('cloud downloaded. start uploading...')
+                    print('cloud downloaded. start uploading...')
                     ret, e = minio.upload_file(e, bucket, bucket_name)
                     if ret:
                         cache_engine.cache('tmp_file_{}_{}'.format(bucket, bucket_name), {
                             'ret': True, 
                             'url': url
                         }, expired=24 * 60 * 60)
-                        # print('upload success!!')
+                        print('upload success!!')
                         
                         if ttl != -1:
                             expired_time = time.time() + ttl * 24 * 60 * 60
@@ -206,6 +207,9 @@ async def extra_tasks():
             affected_records = await ttl_cleanup()
             if affected_records > 0:
                 print('data cleaned')
+
+            if is_time_in_range('04:00', '04:05'):
+                await hmfs_client.cleanup_cloud()
         except:
             traceback.print_exc()
         finally:
